bayespy.nodes.SwitchingGaussianMarkovChain.broadcasting_multiplier
==================================================================

.. currentmodule:: bayespy.nodes

.. automethod:: SwitchingGaussianMarkovChain.broadcasting_multiplier